package com.fr.plugin.heatpointmapbox.ui;

import com.fr.chart.base.TextAttr;
import com.fr.design.gui.frpane.UINumberDragPane;
import com.fr.design.gui.icheckbox.UICheckBox;
import com.fr.design.gui.ilable.UILabel;
import com.fr.design.i18n.Toolkit;
import com.fr.design.layout.TableLayout;
import com.fr.design.layout.TableLayoutHelper;
import com.fr.design.mainframe.chart.gui.style.ChartTextAttrPane;
import com.fr.design.style.color.ColorSelectBox;
import com.fr.extended.chart.ExtendedScrollPane;
import com.fr.general.FRFont;
import com.fr.json.JSONObject;
import com.fr.plugin.heatpointmapbox.HeatPointMapChart;
import com.fr.van.chart.designer.TableLayout4VanChartHelper;

import javax.swing.*;
import java.awt.*;

/**
 * @author xx
 */
public class HeatPointMapStyleTipsPane extends ExtendedScrollPane<HeatPointMapChart> {

    private UICheckBox showPointTips;

    private ColorSelectBox tipBgColor;
    private UINumberDragPane tipBgOpacity;

    private UICheckBox showLayerType;
    private UICheckBox showDataType;
    private UICheckBox showName;
    private UICheckBox showLng;
    private UICheckBox showLat;
    private UICheckBox showDesc;

    private ChartTextAttrPane textAttrPane;

    @Override
    protected JPanel createContentPane() {
        return new ContentPane();
    }

    @Override
    public void populateBean(HeatPointMapChart chart) {
        JSONObject tipsConf = chart.getTipsConf();
        this.showPointTips.setSelected(tipsConf.getBoolean("showPointTips"));
        this.tipBgColor.setSelectObject(MapUtil.toColor(tipsConf.getString("tipBgColor")));
        this.tipBgOpacity.populateBean(tipsConf.getDouble("tipBgOpacity"));

        this.showLayerType.setSelected(tipsConf.getBoolean("showLayerType"));
        this.showDataType.setSelected(tipsConf.getBoolean("showDataType"));
        this.showName.setSelected(tipsConf.getBoolean("showName"));
        this.showLng.setSelected(tipsConf.getBoolean("showLng"));
        this.showLat.setSelected(tipsConf.getBoolean("showLat"));
        this.showDesc.setSelected(tipsConf.getBoolean("showDesc"));

        FRFont tipFont = FRFont.getInstance(tipsConf.getString("tipfamily"),
                tipsConf.getInt("tipstyle"),
                tipsConf.getInt("tipsize"),
                MapUtil.toColor(tipsConf.getString("tipcolor")));
        this.textAttrPane.populate(tipFont);
    }

    @Override
    public void updateBean(HeatPointMapChart chart) {
        JSONObject tipsConf = JSONObject.create();
        tipsConf.put("showPointTips", this.showPointTips.isSelected());
        tipsConf.put("tipBgColor", MapUtil.toHex(this.tipBgColor.getSelectObject()));
        tipsConf.put("tipBgOpacity", this.tipBgOpacity.updateBean());
        tipsConf.put("showLayerType", this.showLayerType.isSelected());
        tipsConf.put("showDataType", this.showDataType.isSelected());
        tipsConf.put("showName", this.showName.isSelected());
        tipsConf.put("showLng", this.showLng.isSelected());
        tipsConf.put("showLat", this.showLat.isSelected());
        tipsConf.put("showDesc", this.showDesc.isSelected());

        TextAttr labelAttr = this.textAttrPane.update();
        tipsConf.put("tipsize", labelAttr.getFRFont().getSize());
        tipsConf.put("tipstyle", labelAttr.getFRFont().getStyle());
        tipsConf.put("tipfamily", labelAttr.getFRFont().getFamily());
        tipsConf.put("tipcolor", MapUtil.toHex(labelAttr.getFRFont().getForeground()));

        chart.setTipsConf(tipsConf);
    }

    @Override
    protected String title4PopupWindow() {
        return Toolkit.i18nText("Plugin-HeatPointMap-tipstitle");
    }

    private class ContentPane extends JPanel {
        public ContentPane() {
            initComponents();
        }

        private void initComponents() {
            this.setLayout(new BorderLayout());

            JPanel contentPane = createTipsContentPane();
            JPanel textStylePane = createTipsTextStylePane();

            double p = TableLayout.PREFERRED;
            double f = TableLayout.FILL;
            double[] columnSize = {f};
            double[] rowSize = {p, p, p, p};
            Component[][] comps = new Component[][]{
                    new Component[]{showPointTips},
                    new Component[]{contentPane},
                    new Component[]{textStylePane}
            };

            JPanel panel = TableLayoutHelper.createTableLayoutPane(comps, rowSize, columnSize);
            this.add(panel, BorderLayout.CENTER);
            this.setVisible(true);
        }
    }

    private JPanel createTipsContentPane() {

        showPointTips = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showPointTips"));
        tipBgColor = new ColorSelectBox(100);
        tipBgOpacity = new UINumberDragPane(0, 100);

        showLayerType = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showLayerType"));
        showDataType = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showDataType"));
        showName = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showName"));
        showLng = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showLng"));
        showLat = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showLat"));
        showDesc = new UICheckBox(Toolkit.i18nText("Plugin-HeatPointMap-showDesc"));

        double p = TableLayout.PREFERRED;
        double f = TableLayout.FILL;
        Component[][] compLabel = new Component[][]{
                {null, null},
                new Component[]{new UILabel(Toolkit.i18nText("Plugin-HeatPointMap-tipBgColor")), this.tipBgColor},
                new Component[]{new UILabel(Toolkit.i18nText("Plugin-HeatPointMap-tipBgOpacity")), this.tipBgOpacity}
        };
        JPanel bgPane = TableLayout4VanChartHelper.createGapTableLayoutPane(compLabel, new double[]{p, p, p}, new double[]{p, f});

        Component[][] compCheck = new Component[][]{
                new Component[]{showDataType, showName},
                new Component[]{showLng, showLat},
                new Component[]{showDesc, null}
        };
        JPanel checkPane = TableLayout4VanChartHelper.createGapTableLayoutPane(compCheck, new double[]{p, p, p, p}, new double[]{p, f});

        Component[][] comp = new Component[][]{
                new Component[]{bgPane},
                new Component[]{checkPane}
        };
        JPanel pane = TableLayout4VanChartHelper.createGapTableLayoutPane(comp, new double[]{p, p, p}, new double[]{f});

        return TableLayout4VanChartHelper.createExpandablePaneWithTitle(Toolkit.i18nText("Plugin-HeatPointMap-tipsAlignExpand"), pane);
    }

    private JPanel createTipsTextStylePane() {
        this.textAttrPane = new ChartTextAttrPane();
        return TableLayout4VanChartHelper.createExpandablePaneWithTitle(Toolkit.i18nText("Plugin-HeatPointMap-tipsTextStyle"), this.textAttrPane);
    }

}
